@@ -1,3 +1,4 @@
+
 /*===========================================================================*/
 /*                                                                           */
 /* This file is part of the SYMPHONY MILP Solver Framework.                  */
@@ -5,7 +6,7 @@
 /* SYMPHONY was jointly developed by Ted Ralphs (ted@lehigh.edu) and         */
 /* Laci Ladanyi (ladanyi@us.ibm.com).                                        */
 /*                                                                           */
-/* (c) Copyright 2000-2013 Ted Ralphs. All Rights Reserved.                  */
+/* (c) Copyright 2000-2014 Ted Ralphs. All Rights Reserved.                  */
 /*                                                                           */
 /* This software is licensed under the Eclipse Public License. Please see    */
 /* accompanying file for terms.                                              */
@@ -159,8 +160,10 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
    int max_presolve_iter = 5;
    const int bc_level = p->bc_level;
    int strong_br_min_level = p->par.strong_br_min_level;
- 
-   /*------------------------------------------------------------------------*\
+
+   used_time(&total_time);
+
+   /*---------------------------------------------------------------------* \
     * First we call select_candidates_u() to select candidates. It can
     * -- return with DO_BRANCH and a bunch of candidates, or
     * -- return with DO_NOT_BRANCH along with a bunch of violated cuts
@@ -180,14 +183,6 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
     case DO_NOT_BRANCH:
       if (cand_num)
 	 *cuts += add_violated_slacks(p, cand_num, candidates);
-#ifdef DO_TESTS
-      if (*cuts == 0 && new_vars == 0){
-	 printf("Error! Told not to branch, but there are no new cuts or ");
-	 printf("variables!\n");
-	 *candidate = NULL;
-	 return(ERROR__NO_BRANCHING_CANDIDATE);
-      }
-#endif
       /* Free the candidates */
       if (candidates){
 	 for (i=0; i<cand_num; i++){
@@ -213,7 +208,6 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
    p->comp_times.strong_branching += used_time(&p->tt);
 #pragma omp critical(cut_pool)
    send_cuts_to_pool(p, -1);
-   send_node_desc(p, NODE_BRANCHED_ON);
    p->comp_times.communication += used_time(&p->tt);
 
    /* Add all the branching cuts */
@@ -256,6 +250,11 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
    st_time     = used_time(&total_time);
    total_iters = 0;
 
+   int *cstat = lp_data->tmp.i1;
+   int *rstat = lp_data->tmp.i2;
+
+   get_basis(lp_data, cstat, rstat);
+      
    if (should_use_rel_br==TRUE) {
 
       const double lpetol100 = lp_data->lpetol*100;
@@ -527,7 +526,6 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
 	    int backtrack = 0;
 
 	    bc_node *node = p->tm->active_nodes[p->proc_index];	    
-	    node = p->tm->active_nodes[p->proc_index];      
 	    if(p->bc_level >= 1){   
 	       while(node->parent){
 		  if(node->start_objval > node->parent->end_objval){
@@ -758,7 +756,11 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
 
       if (1.0*p->lp_stat.str_br_total_iter_num > str_br_cnt_limit) str_br_iter_limit = TRUE; 
 
+#ifdef COMPILE_IN_LP
       int node_factor = (int)(p->tm->stat.analyzed/50.0);
+#else
+      int node_factor = 0;
+#endif
       double int_factor = 0.5; 
       if (p->mip->mip_inf){
 	 int int_var_num = p->mip->n - p->mip->mip_inf->binary_var_num - p->mip->mip_inf->cont_var_num;
@@ -781,7 +783,11 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
 	 }
       }
 
-      if (p->tm->stat.analyzed > 5e5 || p->lp_stat.str_br_total_iter_num > 5e5) {
+      if (
+#ifdef COMPILE_IN_LP
+	  p->tm->stat.analyzed > 5e5 ||
+#endif
+	  p->lp_stat.str_br_total_iter_num > 5e5) {
 	 str_br_iter_limit = TRUE;      
       }
 
@@ -1452,7 +1458,9 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
          if (should_use_hot_starts && unmark_hs){
             unmark_hotstart(lp_data);
             set_itlim_hotstart(lp_data, -1);
-         } 
+         }else{
+	    load_basis(lp_data, rstat, cstat);
+	 }
          set_itlim(lp_data, -1); //both limits should be set for hotstarts
          return (DO_NOT_BRANCH__FATHOMED);
       }
@@ -1467,6 +1475,9 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
        * and only variable bounds are changed then, hot-starts should be faster
        */
       
+#ifdef __OSI_CLP__
+      lp_data->si->setupForRepeatedUse(2,0);
+#endif
       if (p->par.use_hot_starts && !p->par.branch_on_cuts) {
 	 should_use_hot_starts = TRUE;
       } else {
@@ -1485,11 +1496,11 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
 	    max_presolve_iter = 5;
 	 }
 	 if(should_use_hot_starts){
-	   set_itlim_hotstart(lp_data, max_presolve_iter);
+	    set_itlim_hotstart(lp_data, max_presolve_iter);
 	 }
 	 set_itlim(lp_data, max_presolve_iter);
       }
-      
+
       for (i=0; i<cand_num; i++){
          can = candidates[i];
 
@@ -1576,6 +1587,7 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
                   can->termcode[j] = solve_hotstart(lp_data, can->iterd+j);
                   total_iters+=*(can->iterd+j);
                } else {
+		  load_basis(lp_data, cstat, rstat);
                   can->termcode[j] = dual_simplex(lp_data, can->iterd+j);
                   total_iters+=*(can->iterd+j);
                }
@@ -1874,12 +1886,15 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
             break;
          }
          st_time += used_time(&total_time);
-         should_continue_strong_branching(p,i,cand_num,st_time,total_iters,
-               &should_continue);
-         if (should_continue==FALSE) {
-            PRINT(p->par.verbosity, 0, 
-                  ("too much time in strong branching, breaking\n"));
-            break;
+
+         if (p->par.limit_strong_branching_time){
+	    should_continue_strong_branching(p,i,cand_num,st_time,total_iters,
+					     &should_continue);
+	    if (should_continue==FALSE) {
+	       PRINT(p->par.verbosity, 2, 
+		     ("too much time in strong branching, breaking\n"));
+	       break;
+	    }
          }
       }
    }
@@ -1888,8 +1903,12 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
 
    if (should_use_hot_starts && unmark_hs) {
       unmark_hotstart(lp_data);
+      set_itlim_hotstart(lp_data, -1);
+   }else{
+      load_basis(lp_data, cstat, rstat);
    }
-
+   set_itlim(lp_data, -1);
+	    
 #if 0
    if (best_can->type == CANDIDATE_VARIABLE &&
        vars[best_can->position]->lb == vars[best_can->position]->ub){
@@ -1958,6 +1977,9 @@ int select_branching_object(lp_prob *p, int *cuts, branch_obj **candidate)
 
    *candidate = best_can;
    
+   p->comp_times.strong_branching += used_time(&p->tt);
+   send_node_desc(p, NODE_BRANCHED_ON);
+   p->comp_times.communication += used_time(&p->tt);
    return(DO_BRANCH);
 }
 
@@ -2231,9 +2253,11 @@ void branch_close_to_half(lp_prob *p, int max_cand_num, int *cand_num,
       *cand_num = cnt;
    }
 
+#ifdef COMPILE_IN_LP
    p->tm->active_nodes[p->proc_index]->frac_cnt = cnt; 
    p->tm->active_nodes[p->proc_index]->frac_avg = frac_avg; 
-
+#endif
+   
    if (should_use_rel_br == TRUE) {
       *candidates = (branch_obj **) malloc(1 * sizeof(branch_obj *));
       cand = (*candidates)[0] = (branch_obj *) calloc(1, sizeof(branch_obj) );
@@ -2418,7 +2442,6 @@ int should_continue_strong_branching(lp_prob *p, int i, int cand_num,
    *should_continue = TRUE;
    int min_cands;
    int verbosity = p->par.verbosity;
-   //verbosity = 20;
    if (p->bc_level<1) {
       allowed_time = 20*p->comp_times.lp/p->iter_num;
       //allowed_iter = 20*p->lp_stat.lp_total_iter_num/(p->iter_num + 1);
@@ -2477,7 +2500,9 @@ int strong_branch(lp_prob *p, int branch_var, double lb, double ub,
 {
    int status = 0;
    LPdata *lp_data = p->lp_data;
-   
+   int *cstat = lp_data->tmp.i1;
+   int *rstat = lp_data->tmp.i2;
+
    // TODO: LP_ABANDONED
    /* change the lb and ub */
    if(sos_cnt < 1){
@@ -2492,6 +2517,7 @@ int strong_branch(lp_prob *p, int branch_var, double lb, double ub,
    if (should_use_hot_starts) {
       *termstatus = solve_hotstart(lp_data, iterd);
    } else {
+      load_basis(lp_data, cstat, rstat);
       *termstatus = dual_simplex(lp_data, iterd);
    }
    
