@@ -5,7 +5,7 @@
 /* SYMPHONY was jointly developed by Ted Ralphs (ted@lehigh.edu) and         */
 /* Laci Ladanyi (ladanyi@us.ibm.com).                                        */
 /*                                                                           */
-/* (c) Copyright 2000-2013 Ted Ralphs. All Rights Reserved.                  */
+/* (c) Copyright 2000-2014 Ted Ralphs. All Rights Reserved.                  */
 /*                                                                           */
 /* The OSI interface in this file was written by Menal Guzelsoy.             */
 /* The OSL interface was written by Ondrej Medek.                            */
@@ -19,6 +19,10 @@
 #include <memory.h>
 #include <math.h>
 
+#ifdef _OPENMP
+#include "omp.h"
+#endif
+
 #include "sym_lp.h"
 #include "sym_master.h" 
 #include "sym_proccomm.h"
@@ -27,7 +31,9 @@
 #include "sym_macros.h"
 #include "sym_types.h"
 #include "sym_lp_solver.h"
+#ifdef COMPILE_IN_LP
 #include "sym_primal_heuristics.h"
+#endif
 #include "sym_qsort.h"
 #ifdef USE_CGL_CUTS
 #include "sym_cg.h"
@@ -127,9 +133,9 @@ int receive_lp_data_u(lp_prob *p)
       if (has_colnames){
 	 mip->colname = (char **) malloc(sizeof(char *) * mip->n);   
 	 for (i = 0; i < mip->n; i++){
-	    mip->colname[i] = (char *) malloc(CSIZE * 9);
-	    receive_char_array(mip->colname[i], 8);
-	    mip->colname[i][8] = 0;
+	    mip->colname[i] = (char *) malloc(CSIZE * MAX_NAME_SIZE);
+	    receive_char_array(mip->colname[i], MAX_NAME_SIZE);
+	    mip->colname[i][MAX_NAME_SIZE-1] = 0;
 	 }
       }
    }
@@ -260,11 +266,11 @@ int create_subproblem_u(lp_prob *p)
       userind[i] = vars[i]->userind;
       if (userind[i]!=i) {
          p->par.is_userind_in_order = FALSE;
-	 printf("K1\n");
       }
    }
+   /*This is always violated for multi_crtieria due to the addition of the
+     artificial variable. It's probably not needed...*/
    if (lp_data->n != p_mip->n) {
-     printf("K2\n");
       p->par.is_userind_in_order = FALSE;
    }
    
@@ -483,6 +489,7 @@ int create_subproblem_u(lp_prob *p)
    rhs = lp_data_mip->rhs;
    rngval = lp_data_mip->rngval;
    sense = lp_data_mip->sense;
+   assert(bcutnum == p->mip->m);
    for (i = bcutnum - 1; i >= 0; i--){
       row = rows + i;
       cut = row->cut;
@@ -596,7 +603,7 @@ int create_subproblem_u(lp_prob *p)
    //lp_data->frac_var_cnt = p->frac_var_cnt; 
 
    if(p->tm->root_lp == NULL){
-     p->root_lp = (double *)calloc(p->mip->n, DSIZE);
+     p->root_lp = (double *)calloc(p->mip->n+1, DSIZE);
      p->tm->root_lp = p->root_lp;
     }else{
      p->root_lp = p->tm->root_lp;
@@ -882,15 +889,15 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
       break;
    }
 
+#ifdef COMPILE_IN_LP
+
    if(p->bc_index < 1 && p->lp_stat.lp_calls < 2){
      memcpy(p->root_lp, x, DSIZE*n);
    }
 
-#ifdef COMPILE_IN_LP
-
    double t_lb = p->lp_data->objval;   
-   if((p->tm->samephase_candnum > 1 || p->tm->active_node_num > 1)){      
-      find_tree_lb(p->tm);
+   if(p->tm->stat.analyzed > 1){      
+      //find_tree_lb(p->tm);
       t_lb = MIN(t_lb, p->tm->lb);
    } 
 
@@ -918,7 +925,7 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
       
       do_primal_heuristic = TRUE;
    }
-   
+
    if(do_primal_heuristic){
       /* try rounding first */
 
@@ -1066,7 +1073,7 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
 	}
       }
    }
-
+   
    if(user_res == TEST_INTEGRALITY &&
       p->par.do_primal_heuristic && (feasible == IP_FEASIBLE || feasible == IP_HEUR_FEASIBLE) &&
       (p->par.ls_enabled || p->par.lb_enabled) && !p->par.multi_criteria){      
@@ -1107,18 +1114,19 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
 
 #endif
    
-   if (feasible == IP_FEASIBLE && p->par.multi_criteria){
-      cnt = collect_nonzeros(p, lp_data->x, indices, values);
+   if ((feasible == IP_FEASIBLE || feasible == IP_HEUR_FEASIBLE)
+       && p->par.multi_criteria){
+      if (feasible == IP_HEUR_FEASIBLE || force_heur_sol) {
+         cnt = collect_nonzeros(p, heur_solution, indices, values);        
+      } else {
+         cnt = collect_nonzeros(p, lp_data->x, indices, values);        
+      }
       if (analyze_multicriteria_solution(p, indices, values, cnt,
-					 &true_objval, lpetol, branching) > 0){
-	 if(feasible == IP_FEASIBLE){
-	    if (p->par.mc_add_optimality_cuts || branching){
+					 &true_objval, lpetol, branching,
+					 feasible) > 0){
+	 if(feasible == IP_FEASIBLE &&
+	    (p->par.mc_add_optimality_cuts || branching)){
 	       feasible = IP_FEASIBLE_BUT_CONTINUE;
-	    }else{
-	       feasible = IP_FEASIBLE;
-	    }
-	 }else{
-	    feasible = IP_FEASIBLE;
 	 }
       }
    }
@@ -1141,6 +1149,7 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
           */
          true_objval = floor(true_objval+0.5);
       }
+
       /* Send the solution value to the treemanager */
       if (p->has_ub && true_objval >= p->ub - p->par.granularity){
 	 if (!p->par.multi_criteria){
@@ -1158,7 +1167,9 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
       }
       p->has_ub = TRUE;
       p->ub = true_objval;
+#ifdef COMPILE_IN_LP
       p->tm->lp_stat.ip_sols++;
+#endif
       if (p->par.set_obj_upper_lim) {
 	 set_obj_upper_lim(p->lp_data, p->ub - p->par.granularity + lpetol);
       }
@@ -1186,10 +1197,10 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
 		  ("****** After Calling Heuristics !\n"));
 	 }
 	 if (p->mip->obj_sense == SYM_MAXIMIZE){
-	    PRINT(p->par.verbosity, 1, ("****** Cost: %f\n\n", -true_objval
+	    PRINT(p->par.verbosity, 0, ("****** Cost: %f\n\n", -true_objval
 					+ p->mip->obj_offset));
 	 }else{
-	    PRINT(p->par.verbosity, 1, ("****** Cost: %f\n\n", true_objval
+	    PRINT(p->par.verbosity, 0, ("****** Cost: %f\n\n", true_objval
 					+ p->mip->obj_offset));
 	 }
       }
@@ -1198,10 +1209,12 @@ int is_feasible_u(lp_prob *p, char branching, char is_last_iter)
       {
 	 install_new_ub(p->tm, p->ub, p->proc_index, p->bc_index, branching,
 			feasible);
-	 if (p->bc_index>0) {
-	    tighten_root_bounds(p);
-	 }
       }
+#if 0
+      if (p->bc_index>0) {
+	 tighten_root_bounds(p);
+      }
+#endif
       if (!p->par.multi_criteria){
 	 display_lp_solution_u(p, DISP_FEAS_SOLUTION);
       }
@@ -1346,7 +1359,7 @@ void display_lp_solution_u(lp_prob *p, int which_sol)
 	 printf("+++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n");
 	 for (i = 0; i < number; i++){
 	    if (xind[i] == p->mip->n) continue; /* For multi-criteria */
-	    printf("%8s %10.7f\n", p->mip->colname[xind[i]], xval[i]);
+	    printf("%-50s %10.7f\n", p->mip->colname[xind[i]], xval[i]);
 	 }
 	 printf("\n");
       }else{
@@ -1380,7 +1393,7 @@ void display_lp_solution_u(lp_prob *p, int which_sol)
 	    if (xind[i] == p->mip->n) continue; /* For multi-criteria */
 	    tmpd = xval[i];
 	    if ((tmpd > floor(tmpd)+lpetol) && (tmpd < ceil(tmpd)-lpetol)){
-	       printf("%8s %10.7f\n", p->mip->colname[xind[i]], tmpd);
+	       printf("%-50s %10.7f\n", p->mip->colname[xind[i]], tmpd);
 	    }
 	 }
 	 printf("\n");
@@ -2734,8 +2747,9 @@ void free_prob_dependent_u(lp_prob *p)
 /*===========================================================================*/
 
 int analyze_multicriteria_solution(lp_prob *p, int *indices, double *values,
-				    int length, double *true_objval,
-				    double etol, char branching)
+				   int length, double *true_objval,
+				   double etol, char branching,
+				   int feasible)
 {
   double obj[2] = {0.0, 0.0};
   int i;
@@ -2764,13 +2778,17 @@ int analyze_multicriteria_solution(lp_prob *p, int *indices, double *values,
 			      (obj[0] >= p->obj[0] - etol
 			       && obj[1] < p->obj[1] - etol))){
 	    if (p->par.verbosity >= 1){
-	       printf("\nBetter Solution Found:\n");
-	       if(p->mip->obj_sense == SYM_MAXIMIZE){
-		  printf("First Objective Cost: %.1f\n", -obj[0]);
-		  printf("Second Objective Cost: %.1f\n", -obj[1]);
+	       if (feasible == IP_HEUR_FEASIBLE){
+		  printf("\n****** Better Solution Found (Heuristic):\n");
 	       }else{
-		  printf("First Objective Cost: %.1f\n", obj[0]);
-		  printf("Second Objective Cost: %.1f\n", obj[1]);
+		  printf("\n****** Better Solution Found:\n");
+	       }
+	       if(p->mip->obj_sense == SYM_MAXIMIZE){
+		  printf("****** First Objective Cost: %.1f\n", -obj[0]);
+		  printf("****** Second Objective Cost: %.1f\n\n", -obj[1]);
+	       }else{
+		  printf("****** First Objective Cost: %.1f\n", obj[0]);
+		  printf("****** Second Objective Cost: %.1f\n\n", obj[1]);
 	       }
 	    }
 	    p->obj[1] = obj[1];
@@ -2802,13 +2820,17 @@ int analyze_multicriteria_solution(lp_prob *p, int *indices, double *values,
 			      (obj[1] >= p->obj[1] - etol
 			       && obj[0] < p->obj[0] - etol))){
 	   if (p->par.verbosity >= 1){
-	      printf("\nBetter Solution Found:\n");
-	      if(p->mip->obj_sense == SYM_MAXIMIZE){
-		 printf("First Objective Cost: %.1f\n", -obj[0]);
-		 printf("Second Objective Cost: %.1f\n", -obj[1]);
+	      if (feasible == IP_HEUR_FEASIBLE){
+		 printf("\n****** Better Solution Found (Heuristic):\n");
 	      }else{
-		 printf("First Objective Cost: %.1f\n", obj[0]);
-		 printf("Second Objective Cost: %.1f\n", obj[1]);
+		 printf("\n****** Better Solution Found:\n");
+	      }
+	      if(p->mip->obj_sense == SYM_MAXIMIZE){
+		 printf("****** First Objective Cost: %.1f\n", -obj[0]);
+		 printf("****** Second Objective Cost: %.1f\n\n", -obj[1]);
+	      }else{
+		 printf("****** First Objective Cost: %.1f\n", obj[0]);
+		 printf("****** Second Objective Cost: %.1f\n\n", obj[1]);
 	      }
 	   }
 	   p->obj[1] = obj[1];
@@ -2843,13 +2865,17 @@ int analyze_multicriteria_solution(lp_prob *p, int *indices, double *values,
 	 (obj[1] < p->obj[1] - etol &&
 	  obj[0] < p->obj[0] + etol + MIN(p->par.mc_gamma, p->par.mc_tau))){
 	if (p->par.verbosity >= 1){
-	   printf("\nBetter Solution Found:\n");
-	   if(p->mip->obj_sense == SYM_MAXIMIZE){
-	      printf("First Objective Cost: %.1f\n", -obj[0]);
-	      printf("Second Objective Cost: %.1f\n", -obj[1]);
+	   if (feasible == IP_HEUR_FEASIBLE){
+	      printf("\n****** Better Solution Found (Heuristic):\n");
 	   }else{
-	      printf("First Objective Cost: %.1f\n", obj[0]);
-	      printf("Second Objective Cost: %.1f\n", obj[1]);
+	      printf("\n****** Better Solution Found:\n");
+	   }
+	   if(p->mip->obj_sense == SYM_MAXIMIZE){
+	      printf("****** First Objective Cost: %.1f\n", -obj[0]);
+	      printf("****** Second Objective Cost: %.1f\n\n", -obj[1]);
+	   }else{
+	      printf("****** First Objective Cost: %.1f\n", obj[0]);
+	      printf("****** Second Objective Cost: %.1f\n\n", obj[1]);
 	   }
 	}
 	p->obj[1] = obj[1];
@@ -2925,3 +2951,4 @@ int analyze_multicriteria_solution(lp_prob *p, int *indices, double *values,
   return(continue_with_node);
 
 }
+
