@@ -5,7 +5,7 @@
 /* SYMPHONY was jointly developed by Ted Ralphs (ted@lehigh.edu) and         */
 /* Laci Ladanyi (ladanyi@us.ibm.com).                                        */
 /*                                                                           */
-/* (c) Copyright 2006-2013 Lehigh University. All Rights Reserved.           */
+/* (c) Copyright 2006-2014 Lehigh University. All Rights Reserved.           */
 /*                                                                           */
 /* The author of this file is Menal Guzelsoy                                 */
 /*                                                                           */
@@ -118,18 +118,20 @@ int prep_update_rootdesc(sym_environment *env)
    int i, user_size = env->rootdesc->uind.size;// uind = 0;
    int *user_ind = env->rootdesc->uind.list;
    
-   env->base->cutnum = env->mip->m;
-
-   if (user_size == env->mip->n){
-      return PREP_UNMODIFIED;
-   } else {
+   if (user_size != env->mip->n){
       for (i = 0; i < env->mip->n; i++){
 	 user_ind[i] = i;
       }
    }
    
+   env->base->cutnum = env->mip->m;
    env->rootdesc->uind.size = env->mip->n;
    
+   if (env->par.multi_criteria && !env->par.lp_par.mc_find_supported_solutions){
+      env->base->cutnum += 2;
+      env->rootdesc->uind.size++;
+   }
+
    return PREP_MODIFIED;
 }
 
@@ -151,7 +153,7 @@ int prep_solve_desc (PREPdesc * P)
    int verbosity = params.verbosity;
    int p_level = params.level;
 
-   if (p_level <= 0) {
+   if (p_level < 0) {
      /* preprocessing is not carried out. mipinfo data structures are still
       * filled up */
      PRINT(verbosity, -1, ("Skipping Preprocessor\n"));
@@ -460,9 +462,9 @@ int prep_read_mps(prep_environment *prep, char *infile)
 
    for (j = 0; j < mip->n; j++){
       mip->is_int[j] = mps.isInteger(j);
-      mip->colname[j] = (char *) malloc(CSIZE * 9);
-      strncpy(mip->colname[j], const_cast<char*>(mps.columnName(j)), 9);
-      mip->colname[j][8] = 0;
+      mip->colname[j] = (char *) malloc(CSIZE * MAX_NAME_SIZE);
+      strncpy(mip->colname[j], const_cast<char*>(mps.columnName(j)), MAX_NAME_SIZE);
+      mip->colname[j][MAX_NAME_SIZE-1] = 0;
    }
 
 #if 0
@@ -542,9 +544,9 @@ int prep_read_lp(prep_environment *prep, char *infile)
 
    for (j = 0; j < mip->n; j++){
       mip->is_int[j] = lp.isInteger(j);
-      mip->colname[j] = (char *) malloc(CSIZE * 9);
-      strncpy(mip->colname[j], const_cast<char*>(lp.columnName(j)), 9);
-      mip->colname[j][8] = 0;
+      mip->colname[j] = (char *) malloc(CSIZE * MAX_NAME_SIZE);
+      strncpy(mip->colname[j], const_cast<char*>(lp.columnName(j)), MAX_NAME_SIZE);
+      mip->colname[j][MAX_NAME_SIZE-1] = 0;
    }
 
 #if 0
